@@ -42,14 +42,17 @@ $C2S{GETROOT} =
    "\x40" . "\0\0\0\x0b" .
    "\x2a" . "testscript";
 $S2C{GETROOT} =
-   "\x82" . "\0\0\0\xd0" .
+   "\x82" . "\0\0\0\xde" .
    "\xe2" . "\x29t.TestObj" .
             "\x02\1" .
             "\xa4" . "\x02\1" .
-                     "\x61" . "\x26method"  . "\xa2" . "\x02\2" .
+                     "\x62" . "\x26method"  . "\xa2" . "\x02\2" .
                                                        "\x42" . "\x23int" .
                                                                 "\x23str" .
                                                        "\x23str" .
+                              "\x28noreturn" . "\xa2" . "\x02\2" .
+                                                        "\x40" .
+                                                        "\x20" .
                      "\x61" . "\x25event" . "\xa1" . "\x02\3" .
                                                      "\x42" . "\x23int" .
                                                               "\x23str" .
@@ -125,6 +128,12 @@ $C2S{CALL} =
 $S2C{CALL} =
    "\x82" . "\0\0\0\x09" .
    "\x2810/hello";
+$C2S{CALL_NORETURN} =
+   "\1" . "\0\0\0\x0b" .
+   "\x02\x01" .
+   "\x28noreturn";
+$S2C{CALL_NORETURN} =
+   "\x82" . "\0\0\0\0";
 
 # MSG_SUBSCRIBE
 $C2S{SUBSCRIBE} =
